@@ -3,6 +3,7 @@ from typing import Annotated
 import pytest
 from dirty_equals import IsDict
 from fastapi import FastAPI, Query
+from fastapi.exceptions import FastAPIDeprecationWarning
 from fastapi.testclient import TestClient
 
 from .utils import needs_py310
@@ -10,7 +11,7 @@ from .utils import needs_py310
 
 def get_client():
     app = FastAPI()
-    with pytest.warns(DeprecationWarning):
+    with pytest.warns(FastAPIDeprecationWarning):
 
         @app.get("/items/")
         async def read_items(
