@@ -7,8 +7,6 @@ from fastapi.responses import JSONResponse, Response
 from fastapi.testclient import TestClient
 from pydantic import BaseModel
 
-from tests.utils import needs_pydanticv1
-
 
 class BaseUser(BaseModel):
     name: str
@@ -511,26 +509,6 @@ def test_invalid_response_model_field():
     assert "parameter response_model=None" in e.value.args[0]
 
 
-# TODO: remove when dropping Pydantic v1 support
-@needs_pydanticv1
-def test_invalid_response_model_field_pv1():
-    from fastapi._compat import v1
-
-    app = FastAPI()
-
-    class Model(v1.BaseModel):
-        foo: str
-
-    with pytest.raises(FastAPIError) as e:
-
-        @app.get("/")
-        def read_root() -> Union[Response, Model, None]:
-            return Response(content="Foo")  # pragma: no cover
-
-    assert "valid Pydantic field type" in e.value.args[0]
-    assert "parameter response_model=None" in e.value.args[0]
-
-
 def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
