@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from docs_src.advanced_middleware.tutorial002 import app
+from docs_src.advanced_middleware.tutorial002_py39 import app
 
 
 def test_middleware():
