@@ -15,7 +15,7 @@ from tests.utils import needs_py310
     ],
 )
 def get_client(request: pytest.FixtureRequest):
-    mod = importlib.import_module(f"docs_src.dataclasses.{request.param}")
+    mod = importlib.import_module(f"docs_src.dataclasses_.{request.param}")
 
     client = TestClient(mod.app)
     client.headers.clear()
